bbprep.Modifier
===============

.. currentmodule:: bbprep

.. autoclass:: Modifier
   :members:

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Modifier.modify
   
   

   
   
   